#
# spec file for package perl-Furl
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Furl
Name:           perl-Furl
Version:        3.14
Release:        1.15
Summary:        Lightning-fast URL fetcher
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/S/SY/SYOHEX/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
Patch0:         0001-Remove-use-of-Mozilla-CA.patch
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Class::Accessor::Lite)
BuildRequires:  perl(HTTP::Parser::XS) >= 0.11
BuildRequires:  perl(Module::Build::Tiny) >= 0.035
#BuildRequires:  perl(Mozilla::CA)
BuildRequires:  perl(Test::More) >= 0.96
BuildRequires:  perl(Test::Requires)
BuildRequires:  perl(Test::TCP) >= 2.11
Requires:       perl(Class::Accessor::Lite)
Requires:       perl(HTTP::Parser::XS) >= 0.11
#Requires:       perl(Mozilla::CA)
Recommends:     perl(Compress::Raw::Zlib)
Recommends:     perl(HTTP::CookieJar)
Recommends:     perl(IO::Socket::SSL)
Recommends:     perl(Net::IDN::Encode)
%{perl_requires}

%description
Furl is yet another HTTP client library. LWP is the de facto standard HTTP
client for Perl 5, but it is too slow for some critical jobs, and too
complex for weekend hacking. Furl resolves these issues. Enjoy it!

%prep
%autosetup  -n %{cpan_name}-%{version} -p1

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes example README.md TODO
%license LICENSE

%changelog
* Fri May 14 2021 Tina Müller <tina.mueller@suse.com>
- Add 0001-Remove-use-of-Mozilla-CA.patch patch to cpanspec.yml
* Fri May 14 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.14
  see /usr/share/doc/packages/perl-Furl/Changes
  3.14 2021-05-13T05:30:22Z
  - Support 308 HTTP status code
* Wed Jul 24 2019 Marius Kittler <marius.kittler@suse.com>
- Add 0001-Remove-use-of-Mozilla-CA.patch to actually patch out
  Mozilla::CA dependency to rely on system-wide certificates
* Wed Jul 17 2019 Oliver Kurz <okurz@suse.com>
- Patch out Mozilla::CA dependency to rely on system-wide certificates
* Mon Oct  9 2017 coolo@suse.com
- updated to 3.13
  see /usr/share/doc/packages/perl-Furl/Changes
  3.13 2017-09-19T06:31:34Z
  - Fixed test code(skaji++)
  3.12 2017-09-13T06:58:15Z
    commit 88cd747c78d80675c1aa4953083af16f70085252
    Author: Shoichi Kaji <skaji@cpan.org>
    Date:   Mon Aug 14 00:50:55 2017 +0900
    check whether sockets are readable or not before reusing them
    commit 90f3e48ce20845e0f11be40bb975f9c23c86ad8a
    Author: ktat <ktat.is@gmail.com>
    Date:   Mon May 29 14:26:55 2017 +0900
    uri_unescape user & password for Basic auth
* Thu May 18 2017 coolo@suse.com
- updated to 3.11
  see /usr/share/doc/packages/perl-Furl/Changes
  3.11 2017-05-16T23:54:24Z
  - added docs
* Thu Apr  6 2017 coolo@suse.com
- updated to 3.10
  see /usr/share/doc/packages/perl-Furl/Changes
  3.10 2017-04-05T16:52:32Z
  - Fix tests for newer Perl @INC issue
* Fri Jul 22 2016 coolo@suse.com
- updated to 3.09
  see /usr/share/doc/packages/perl-Furl/Changes
  3.09 2016-07-21T14:10:52Z
  - Support 1xx status
  - Fix test on Windows issue
  - Fix httpoxy
* Sat Aug  8 2015 coolo@suse.com
- updated to 3.08
  see /usr/share/doc/packages/perl-Furl/Changes
  3.08 2015-08-06T09:32:19Z
  - Handle cookies while redirection.
    (tokuhirom)
  - delete method accept message body
    (kimoto)
* Wed Apr 22 2015 coolo@suse.com
- updated to 3.07
  see /usr/share/doc/packages/perl-Furl/Changes
  3.07 2015-04-21T03:42:39Z
  - Depends on latest Test::TCP
    https://github.com/tokuhirom/Test-TCP/issues/31#issuecomment-94378132
* Mon Apr 13 2015 coolo@suse.com
- updated to 3.06
  see /usr/share/doc/packages/perl-Furl/Changes
* Tue Sep  6 2011 pascal.bleser@opensuse.org
- update to 0.38:
  * added ->agent method
- changes from 0.37:
  * fixed SSL closing issue
- changes from 0.35:
  * compensate for slash of path-query
- changes from 0.34:
  * accept the domain using '_' character
- changes from 0.33:
  * support url doesn't have trailing slash like
    'http://example.com?gfx=isogashi'
* Mon May 30 2011 pascal.bleser@opensuse.org
- update to 0.32:
  * remove duplicated Host header on high level API(xaicron)
* Sun Feb 27 2011 pascal.bleser@opensuse.org
- update to 0.31:
  * CarpLevel++
* Fri Feb 25 2011 pascal.bleser@opensuse.org
- update to 0.30:
  * allow '0000000' as end of chunked response
* Thu Feb 24 2011 pascal.bleser@opensuse.org
- update to 0.29:
  * fixed bug on proxy with redirect
  * add support for 307 (it was not handled as a redirect), with tests for all
    redirects (307 is implemented the same as 301, preserving the original
    requesting method)
* Thu Feb 17 2011 pascal.bleser@opensuse.org
- update to 0.26: tiny pod fix
* Thu Feb 17 2011 pascal.bleser@opensuse.org
- update to 0.25 (no user-visible changes)
* Tue Feb  8 2011 pascal.bleser@opensuse.org
- update to 0.24 (no user-visible changes)
- changes from 0.23:
  * properly implement Furl::env_proxy as a delegate to Furl::HTTP::env_proxy
    (as was already documented)
* Thu Jan 27 2011 pascal.bleser@opensuse.org
- update to 0.22:
  * remove default ports from the Host header
- changes from 0.21:
  * use keep-alive on redirection, do not activate the "write_code" or the
    "write_func" feature when redirection
  * silently try to resend a request only when the server returned no respnose
    at all
- changes from 0.20:
  * add internal error response message to status message
- changes from 0.19:
  * errorneously returned 500 error when closing of the socket was used to
    indicate eof (i.e. no Content-Encoding or Content-Length)
- changes from 0.18:
  * fixed testing issue
- changes from 0.17:
  * only send the connection header with the highest precedence (Furl::request
    => Furl::new)
  * close the connection when furl requested as such, even if the server sent
    "connection: keep-alive"
  * support keep-alive for $furl->request(method => 'HEAD', headers => [
    qw(connection keep-alive) ])
  * always send the connection header (support for automatic keep-alive with
    HTTP/1.0 servers)
* Thu Dec  2 2010 pascal.bleser@opensuse.org
- add new Requires: perl(Net::DNS::Lite) (dependency was introduced in 0.14)
- update to 0.16:
  * support for status codes wo. content
- changes from 0.15:
  * doc enhancements
- changes from 0.14:
  * changed the semantics of the "timeout" parameter from per-IO timeout to request timeout
  * optional support for name resolution timeouts using Net::DNS::Lite
  * make blocking operations cancellable (through the "stop_if" callback)
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Wed Nov 17 2010 pascal.bleser@opensuse.org
- update to 0.13:
  * do not die when $content is empty string
- changes from 0.12:
  * fixed testing issue
* Fri Nov  5 2010 pascal.bleser@opensuse.org
- update to 0.11 (no user-visible changes)
* Wed Nov  3 2010 pascal.bleser@opensuse.org
- update to 0.10:
  * change request() to accept HTTP::Request, and remove request_with_http_request
  * Furl::ConnPool.pm was renamed to Furl::ConnectionCache.pm
* Tue Nov  2 2010 pascal.bleser@opensuse.org
- update to 0.09: no user-visible changes
- changes from 0.08:
  * rewrote connection pooling strategy
  * updated docs
  * support relative url in redirection
* Tue Nov  2 2010 pascal.bleser@opensuse.org
- initial package (0.07)
